[Pkg-owncloud-commits] [owncloud-client] 247/333: SyncEngine: new aboutToPropagate signal

Sandro Knauß hefee-guest at moszumanska.debian.org
Thu Apr 17 23:16:59 UTC 2014


This is an automated email from the git hooks/post-receive script.

hefee-guest pushed a commit to branch master
in repository owncloud-client.

commit 54313338cd2cc316ccfbff5600ba93b56c636524
Author: Markus Goetz <markus at woboq.com>
Date:   Thu Mar 27 17:04:31 2014 +0100

    SyncEngine: new aboutToPropagate signal
---
 src/mirall/syncengine.cpp | 1 +
 src/mirall/syncengine.h   | 4 +++-
 2 files changed, 4 insertions(+), 1 deletion(-)

diff --git a/src/mirall/syncengine.cpp b/src/mirall/syncengine.cpp
index e4ac7cf..0c931c6 100644
--- a/src/mirall/syncengine.cpp
+++ b/src/mirall/syncengine.cpp
@@ -537,6 +537,7 @@ void SyncEngine::slotUpdateFinished(int updateResult)
     }
 
     // To announce the beginning of the sync
+    emit aboutToPropagate(_syncedItems);
     emit transmissionProgress(_progressInfo);
 
     if (!_hasFiles && !_syncedItems.isEmpty()) {
diff --git a/src/mirall/syncengine.h b/src/mirall/syncengine.h
index 79b75a4..7844f7d 100644
--- a/src/mirall/syncengine.h
+++ b/src/mirall/syncengine.h
@@ -67,8 +67,10 @@ signals:
     void csyncWarning( const QString& );
     void csyncUnavailable();
 
     // before actual syncing (after update+reconcile)
     void syncItemDiscovered(const SyncFileItem&);
+    // after the above signals. with the items that actually need propagating
+    void aboutToPropagate(const SyncFileItemVector&);
 
     // after each job (successful or not)
     void jobCompleted(const SyncFileItem&);
@@ -67,8 +67,10 @@ signals:
     void csyncUnavailable();
 
-    // before actual syncing (after update+reconcile)
+    // before actual syncing (after update+reconcile) for each item
     void syncItemDiscovered(const SyncFileItem&);

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-owncloud/owncloud-client.git



More information about the Pkg-owncloud-commits mailing list